@@ -25,8 +25,7 @@ from . import enc
 from . import cli
 
 # Metadata
-__version__ = 'v1.0.1'
-"""Package Version"""
+__version__ = 'v1.0.2'
 __stable__ = True
 """If package is stable or not."""
 __source__ = 'https://github.com/Quantalabs/DiffPriv'
@@ -47,7 +46,7 @@ def _sanity_check():
     url = f'https://pypi.python.org/pypi/DiffPriv/json'
 
     if url.lower().startswith('http'):
-        releases = json.loads(request.urlopen(url).read())
+        releases = json.loads(request.urlopen(url).read()) # skipcq
     else: # pragma: no cover
         raise ValueError from None
 
